<template>
    <div class="e-chart-root">
        <div class="e-chart-container">
            <div class="e-chart" :id="id" :ref="id"></div>
        </div>
    </div>
</template>

<script>
// 引入 ECharts 主模块
import ECharts from "echarts/lib/echarts";
//引入折线图
import "echarts/lib/chart/line";
//引入提示框
import "echarts/lib/component/tooltip";
//引入标题
import "echarts/lib/component/title";
//引入图例标志
import "echarts/lib/component/legend";
//区域缩放
import "echarts/lib/component/dataZoom";

//markeline
import "echarts/lib/component/markLine"

// 引入自定义主题
import "./theme/transparent"

export default {
    props: {
        id: {
            type: String,
            required: true,
        },
        unit: {
            type: String,
            default: '',
        }
    },
    methods:{
        setOption(opt) {
            let unit = this.unit;
            // 整体配置项
            let option = {
                animation: false,
                color: this.getColor(opt),
                title: this.getTitle(opt),
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {            // 坐标轴指示器，坐标轴触发有效
                        type: 'line'        // 默认为直线，可选为：'line' | 'shadow'
                    },
                    appendToBody: true,
                    formatter(params){
                        var res = params[0].name+'<br/>';
                        params.forEach(item=>{
                            res += item.marker;
                            res += item.seriesName;
                            res +=' : '+item.data[1]+unit+'</br>';
                        });
                        return res;
                    }
                },
                grid: {
                    left: '1%',
                    right: '1%',
                    bottom: '2%',
                    containLabel: true
                },
                legend: this.getLegend(opt),
                xAxis: [
                    {
                        type: 'category',
                        boundaryGap: 0,
                    }
                ],
                yAxis: [
                    {
                        type: 'value',
                        splitLine: {
                            show: true,
                        },
                        min: function(data) {
                            let min = data.min;
                            if(min == Infinity) {
                                return 0;
                            }
                            if(min>0) {
                                return Math.floor(min*0.9);
                            }else {
                                return Math.floor(min*1.01);
                            }
                            
                        },
                        max: function(data) {
                            let max = data.max;
                            if(max == -Infinity) {
                                return 1;
                            }
                            return Math.ceil(max*1.01);
                        }
                    }
                ],
                series: this.getSeries(opt),
            };
            // 清理画布
            this.$G.chartManage.get(this.id).clear();
            // 设置配置项
            this.$G.chartManage.get(this.id).setOption(option);
        },
        getColor(opt) {     // 配置自定义颜色
            // 未配置自定义颜色
            if(!opt || !opt.color) {
                return []
            }

            // 返回颜色
            return opt.color;
        },
        getTitle(opt) {     // 配置标题
            // 未配置标题
            if(!opt || !opt.title) {
                return {
                    show: false,
                };
            }

            // 返回标题
            return opt.title;
        },
        getLegend(opt){
            // 未配置legend
            if(!opt || !opt.legend) {
                return {
                    show: false,
                }
            }

            return opt.legend;
        },
        getSeries(opt) {    // 设置series
            // 未配置series
            if(!opt || !opt.series) {
                return [];
            }
            // 设置配置项
            let series = opt.series.map(item=>{
                // 设置类型
                item.type="line";
                // 设置平滑的线条，关闭圆圈，设置采样点
                item.smooth=true;
                item.symbolSize=0;
                item.sampling='average';
                return item;
            });
            // 返回
            return series;
        },
        getMax(list) {
            let arr = list.map(item=>{
                return item[1];
            });
            return Math.max.apply(null,arr);
        },
        getMin(list) {
            let arr = list.map(item=>{
                return item[1];
            });
            return Math.min.apply(null,arr);
        }
    },
    mounted() {
        // 基于准备好的dom，初始化echarts实例
        let chart = ECharts.init(this.$refs[this.id], 'transparent');
        // 将图表添加到图表管理
        this.$G.chartManage.set(this.id, chart);
        // 设置配置项
        this.setOption();
    }
}
</script>

<style scoped>
.e-chart-root,
.e-chart-container,
.e-chart {
    height: 100%;
    box-sizing: border-box;
}
</style>